@@ -30,8 +30,8 @@ class TestRuntimeConfig:
             with raises(KiwiRuntimeConfigFormatError):
                 runtime_config._get_attribute('foo', 'bar')
 
+    @patch('kiwi.defaults.CUSTOM_RUNTIME_CONFIG_FILE', 'some-config-file')
     def test_init_raises_custom_config_file_not_found(self):
-        Defaults.set_custom_runtime_config_file('some-config-file')
         with patch('os.path.isfile', return_value=False):
             with raises(KiwiRuntimeConfigFileError):
                 RuntimeConfig(reread=True)
@@ -93,6 +93,8 @@ class TestRuntimeConfig:
         assert runtime_config.get_iso_tool_category() == 'xorriso'
         assert runtime_config.get_oci_archive_tool() == 'umoci'
         assert runtime_config.get_package_changes() is False
+        assert runtime_config.\
+            get_credentials_verification_metadata_signing_key_file() == ''
 
     def test_config_sections_invalid(self):
         with patch.dict('os.environ', {'HOME': '../data/kiwi_config/invalid'}):
